==> mgb-0.6.9.3.tar.bz2: language/lang_turkish_utf8/lang_import.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// =========================================== //
	// lang_import.php - Turkish by Mustafa Dündar //
	// =========================================== //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// header
	$lang['h_title'] = "Bir önceki sürümden veri alma";

	// general
	$lang['next_step'] = "&raquo; Devam &raquo;";
	$lang['yes'] = "Evet";
	$lang['no'] = "Hayýr";
	$lang['active'] = "Çevrimci";
	$lang['inactive'] = "Çevrim dýþý";
	$lang['ok'] = "TAMAM!";
	$lang['not_ok'] = "Baþarýsýz oldu!";

	// installation
	$lang['title'] = "Bir önceki sürümden veri alma";

	$lang['expl_import'] = "Eski MGB Ziyaretçi Defteri Kurulumu veritabaný bilgilerini giriniz. <b>alan adý</b> vermeden. örnek.: yerine <i>http://www.beispiel.de/php/mgb/</i> sadece <i>/php/mgb/</i>. Verinin baþýna ve sonuna slash i unutmayýnýz.";

	// step 1
	$lang['db_title'] = "Veritabaný bilgileri:";
	$lang['db_hostname'] = "Host:";
	$lang['db_dbname'] = "Veritabaný adý:";
	$lang['db_username'] = "Kullanýcý adý:";
	$lang['db_password'] = "Þifre:";
	$lang['oldgb_path'] = "Dizin:";
	$lang['import_settings'] = "Ayarlarý alma:";

	// errormessages step 1
	$lang['no_error'] = "Tüm verilen veriler tamamdýr!";
	$lang['error_1_step1'] = "Lütfen tüm alanlarý doldurunuz!";
	$lang['error_2_step1'] = "Verilen bilgileri kontrol ediniz. Veritabanýna eriþilememiþtir.";
	$lang['error_3_step1'] = "Senin tarafýndan verilen dizinde, MGB yükleme Programý bulunamamýþtýr.";
	$lang['error_4_step1'] = "Verilen veritabaný doðru fakat, o dizinde yükleme Programý bulunamamýþtýr.";

	// step 2
	$lang['transfer_settings'] = "Tranfer Tercihler...";
	$lang['transfer_entries'] = "Transfer giriþleri...";

	// finish
	$lang['import_finish'] = "Tebrikler!<br><br>Eski MGB bilgileri baþarý ile yeni MGB ".MGB_VERSION." ye transfer olmuþtur.<br><br><a href='../admin/admin.php' title='Yönetici'>Yönetici</a><br><a href='../index.php' title='Müþteri Defteri'>Müþteri Defteri</a>";
?>

==> mgb-0.6.9.5.tar.bz2: language/lang_turkish_utf8/lang_import.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2013 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// =========================
	// lang_import.php - Turkish
	// =========================

	// Translated by Mustafa Dündar
	// ++++++++++++++++++++++++++++

	// header
	$lang['h_title'] = "Bir önceki sürümden veri alma";

	// general
	$lang['next_step'] = "&raquo; Devam &raquo;";
	$lang['yes'] = "Evet";
	$lang['no'] = "Hayýr";
	$lang['active'] = "Çevrimci";
	$lang['inactive'] = "Çevrim dýþý";
	$lang['ok'] = "TAMAM!";
	$lang['not_ok'] = "Baþarýsýz oldu!";

	// installation
	$lang['title'] = "Bir önceki sürümden veri alma";

	$lang['expl_import'] = "Eski MGB Ziyaretçi Defteri Kurulumu veritabaný bilgilerini giriniz. <b>alan adý</b> vermeden. örnek.: yerine <i>http://www.beispiel.de/php/mgb/</i> sadece <i>/php/mgb/</i>. Verinin baþýna ve sonuna slash i unutmayýnýz.";

	// step 1
	$lang['db_title'] = "Veritabaný bilgileri:";
	$lang['db_hostname'] = "Host:";
	$lang['db_dbname'] = "Veritabaný adý:";
	$lang['db_username'] = "Kullanýcý adý:";
	$lang['db_password'] = "Þifre:";
	$lang['oldgb_path'] = "Dizin:";
	$lang['import_settings'] = "Ayarlarý alma:";

	// errormessages step 1
	$lang['no_error'] = "Tüm verilen veriler tamamdýr!";
	$lang['error_1_step1'] = "Lütfen tüm alanlarý doldurunuz!";
	$lang['error_2_step1'] = "Verilen bilgileri kontrol ediniz. Veritabanýna eriþilememiþtir.";
	$lang['error_3_step1'] = "Senin tarafýndan verilen dizinde, MGB yükleme Programý bulunamamýþtýr.";
	$lang['error_4_step1'] = "Verilen veritabaný doðru fakat, o dizinde yükleme Programý bulunamamýþtýr.";

	// step 2
	$lang['transfer_settings'] = "Tranfer Tercihler...";
	$lang['transfer_entries'] = "Transfer giriþleri...";

	// finish
	$lang['import_finish'] = "Tebrikler!<br><br>Eski MGB bilgileri baþarý ile yeni MGB ".MGB_VERSION." ye transfer olmuþtur.<br><br><a href='../admin/admin.php' title='Yönetici'>Yönetici</a><br><a href='../index.php' title='Müþteri Defteri'>Müþteri Defteri</a>";
?>
